@@ -9,10 +9,7 @@ from jupyterhub.auth import LocalAuthenticator
 from tornado.escape import url_escape
 from tornado.httpclient import HTTPRequest
 from tornado.httputil import url_concat
-from traitlets import CUnicode
-from traitlets import default
-from traitlets import Set
-from traitlets import Unicode
+from traitlets import CUnicode, Set, Unicode, default
 
 from .oauth2 import OAuthenticator
 
@@ -118,7 +115,7 @@ class GitLabOAuthenticator(OAuthenticator):
 
         # Exchange the OAuth code for a GitLab Access Token
         #
-        # See: https://github.com/gitlabhq/gitlabhq/blob/master/doc/api/oauth2.md
+        # See: https://github.com/gitlabhq/gitlabhq/blob/HEAD/doc/api/oauth2.md
 
         # GitLab specifies a POST request yet requires URL parameters
         params = dict(
