@@ -1,6 +1,6 @@
 from unittest.mock import Mock
 
-from pytest import fixture
+from pytest import fixture, mark
 from tornado import web
 
 from ..auth0 import Auth0OAuthenticator
@@ -8,6 +8,7 @@ from ..oauth2 import OAuthLogoutHandler
 from .mocks import mock_handler, setup_oauth_mock
 
 auth0_subdomain = "jupyterhub-test"
+auth0_domain = "jupyterhub-test.auth0.com"
 
 
 def user_model(email, nickname=None):
@@ -23,7 +24,7 @@ def user_model(email, nickname=None):
 def auth0_client(client):
     setup_oauth_mock(
         client,
-        host='%s.auth0.com' % auth0_subdomain,
+        host=auth0_domain,
         access_token_path='/oauth/token',
         user_path='/userinfo',
         token_request_style='json',
@@ -31,8 +32,11 @@ def auth0_client(client):
     return client
 
 
-async def test_auth0(auth0_client):
-    authenticator = Auth0OAuthenticator(auth0_subdomain=auth0_subdomain)
+@mark.parametrize(
+    'config', [{"auth0_domain": auth0_domain}, {"auth0_subdomain": auth0_subdomain}]
+)
+async def test_auth0(config, auth0_client):
+    authenticator = Auth0OAuthenticator(**config)
     handler = auth0_client.handler_for_user(user_model('kaylee@serenity.now'))
     user_info = await authenticator.authenticate(handler)
     assert sorted(user_info) == ['auth_state', 'name']
@@ -43,8 +47,11 @@ async def test_auth0(auth0_client):
     assert 'auth0_user' in auth_state
 
 
-async def test_username_key(auth0_client):
-    authenticator = Auth0OAuthenticator(auth0_subdomain=auth0_subdomain)
+@mark.parametrize(
+    'config', [{"auth0_domain": auth0_domain}, {"auth0_subdomain": auth0_subdomain}]
+)
+async def test_username_key(config, auth0_client):
+    authenticator = Auth0OAuthenticator(**config)
     authenticator.username_key = 'nickname'
     handler = auth0_client.handler_for_user(user_model('kaylee@serenity.now', 'kayle'))
     user_info = await authenticator.authenticate(handler)
@@ -53,7 +60,6 @@ async def test_username_key(auth0_client):
 
 
 async def test_custom_logout(monkeypatch):
-    auth0_subdomain = 'auth0-domain.org'
     authenticator = Auth0OAuthenticator()
     logout_handler = mock_handler(OAuthLogoutHandler, authenticator=authenticator)
     monkeypatch.setattr(web.RequestHandler, 'redirect', Mock())
@@ -69,7 +75,7 @@ async def test_custom_logout(monkeypatch):
     assert authenticator.logout_url('http://myhost') == 'http://myhost/logout'
 
     # Check redirection to the custom logout url
-    authenticator.auth0_subdomain = auth0_subdomain
+    authenticator.auth0_domain = auth0_domain
     await logout_handler.get()
-    custom_logout_url = f'https://{auth0_subdomain}.auth0.com/v2/logout'
+    custom_logout_url = f'https://{auth0_domain}/v2/logout'
     logout_handler.redirect.assert_called_with(custom_logout_url)
